/******************************************************************************
 * wanpipe_events.h	
 *
 * Author: 	Alex Feldman  <al.feldman@sangoma.com>
 *
 * Copyright:	(c) 1995-2001 Sangoma Technologies Inc.
 *
 *		This program is free software; you can redistribute it and/or
 *		modify it under the terms of the GNU General Public License
 *		as published by the Free Software Foundation; either version
 *		2 of the License, or (at your option) any later version.
 * ============================================================================
 ******************************************************************************
 */

#ifndef __WANPIPE_EVENTS_H__
# define __WANPIPE_EVENTS_H__

/* DTMF event tone type: present or stop */
#define WAN_EC_TONE_PRESENT		0x01
#define WAN_EC_TONE_STOP		0x02
#define WAN_EC_DECODE_TONE_TYPE(type)					\
		(type == WAN_EC_TONE_PRESENT)	? "Present"	:	\
		(type == WAN_EC_TONE_STOP)	? "Stop" 	:	\
							"Unknown"

/* channel port (sout, rout, sin, rin) */
#define WAN_EC_CHANNEL_PORT_SOUT	0x01
#define WAN_EC_CHANNEL_PORT_SIN		0x02
#define WAN_EC_CHANNEL_PORT_ROUT	0x03
#define WAN_EC_CHANNEL_PORT_RIN		0x04

#define WAN_EVENT_RXHOOK_OFF		0x01
#define WAN_EVENT_RXHOOK_ON		0x02

#define WAN_EVENT_RING_PRESENT		0x01
#define WAN_EVENT_RING_STOP		0x02

#if defined(WAN_KERNEL)

/* Global Event defines 			*/
#define WAN_EVENT_ENABLE	0x80000000
#define WAN_EVENT_DISABLE	0x00000000
#define WAN_EVENT_MODE_DECODE(type)	((type) & WAN_EVENT_ENABLE) ? "Enable" : "Disable"

#define WAN_EVENT_EC_DTMF	0x00000001
#define WAN_EVENT_RM_POWER	0x00000002
#define WAN_EVENT_RM_LC		0x00000004
#define WAN_EVENT_RM_RT		0x00000008
#define WAN_EVENT_RM_DTMF	0x00000010
#define WAN_EVENT_TE_RBS	0x00000020
#define WAN_EVENT_TYPE_DECODE(type)				\
		((type) & WAN_EVENT_EC_DTMF)	? "EC DTMF"  :	\
		((type) & WAN_EVENT_RM_POWER)	? "RM POWER" :	\
		((type) & WAN_EVENT_RM_LC)	? "RM LC" :	\
		((type) & WAN_EVENT_RM_RT)	? "RM RT" :	\
		((type) & WAN_EVENT_RM_DTMF)	? "RM DTMF" :	\
		((type) & WAN_EVENT_TE_RBS)	? "TE RBS" :	"Unknown"

/* Event information			*/
typedef struct wan_event_ {
	unsigned long 	type;
	int		channel;	/* A200-mod_no, T1/E1-fe chan  */
	unsigned char	digit;		/* DTMF: digit  */
	unsigned char	dtmf_type;	/* DTMF: PRESETN/STOP */
	unsigned char	dtmf_port;	/* DTMF: ROUT/SOUT */

	unsigned char	rxhook;		/* LC: OFF-HOOK or ON-HOOK */
	
} wan_event_t;

/* Event control 			*/
typedef struct wan_event_ctrl_ {

	int		mod_no;	/* A200-Remora */	
	unsigned long	type;
	unsigned char	ec_dtmf_port;	/* EC DTMF: SOUT or ROUT */
	unsigned long	ts_map;

} wan_event_ctrl_t;
#endif	/* WAN_KERNEL */

#endif	/* __WANPIPE_EVENTS_H__ */
